use "PONE-D-16-06149.dta", clear
set more off
gen one = 1 // generic indicator


****** DESCRIPTIVES

su year
su year if year > 1959


**** Figure 2: Production of Law Professors

preserve
	collapse (sum) one if year > 1959 & year < 2010, by(year)
	sc one year, c(L) ms(S) ///
	title("all data") xtitle("year") ytitle("# habil")
restore
graph export Fig2.eps, replace


**** Figure 3: Development in the Three Institutionalised Sub-disciplines

preserve
	collapse (sum) one if year > 1959 & year < 2010, by(priv pub crim year)
	two (sc one year if priv, c(L) ms(S)) (sc one year if pub, c(L) ms(T)), ///
	legend(label(1 "private law") label(2 "public law")) ///
	xtitle("year") ytitle("# habil") ///
	name(subdisc2, replace)
restore

preserve
	collapse (sum) one if year > 1959 & year < 2010, by(priv pub crim year)
	two (sc one year if crim, c(L) ms(O) mc(green)) (sc one year if 0==1, ms(i)), ///
	legend(label(1 "criminal law") label(2 "")) ///
	xtitle("year") ytitle("# habil") ///
	name(crim, replace) graphregion(margin(bottom))
restore

graph combine subdisc2 crim, xsize(10) ysize(4)
graph export Fig3.eps, replace


****** ANALYSIS

**** Figure 4: Autocorrelation (absent controls)

preserve
	set more off
	keep if year > 1959 & year < 2010
	collapse (sum) one, by (year)
	su one
	gen id = _n
	gen coef = .
	gen se = .
	tsset year
	forvalues i = 6/22 {
		reg one L`i'.one, robust
		replace coef = _b[L`i'.one] if id == `i'
		replace se = _se[L`i'.one] if id == `i'
		}
	gen high = coef + 1.96*se
	gen low = coef - 1.96*se
	two (rcap high low id if id > 4 & id < 23) (sc coef id if id > 4 & id < 23, c(L) msize(medthick) lw(medthick)) ///
	, name(hog, replace) xtitle("lag") ytitle("degree of autocorrelation") title("no controls") ///
	legend(label(1 "95% confidence interval") label(2 "correlation coefficient")) yline(0)
restore
graph export Fig4.eps, replace


**** Table 1: Pure Autocorrelation

preserve
	keep if year > 1959 & year < 2010
	collapse (sum) one, by (year)
	reg one L9.one, robust
restore


**** Figure 5: Time Trend

preserve
	set more off
	keep if year > 1959 & year < 2010
	collapse (sum) one, by (year)
	gen year2 = year - 1960
	su one
	gen id = _n
	gen coef = .
	gen se = .
	tsset year2
	forvalues i = 6/19 {
		reg one year2 L`i'.one, robust
		replace coef = _b[L`i'.one] if id == `i'
		replace se = _se[L`i'.one] if id == `i'
		}
	reg one year2, robust
	predict predone
	two (sc one year, c(L) ms(S)) (line predone year), ///
	legend(label(1 "observed") label(2 "time trend")) title("regression on time trend") name(trend, replace)
	gen high = coef + 1.96*se
	gen low = coef - 1.96*se
	two (rcap high low id if id > 5 & id < 20) (sc coef id if id > 5 & id < 20, c(L) msize(medthick) lw(medthick)) ///
	, name(timetrend, replace) xtitle("lag") ytitle("degree of autocorrelation") title("lags with control for timetrend") ///
	legend(label(1 "95% confidence interval") label(2 "correlation coefficient")) yline(0)
	graph combine trend timetrend, xsize(10) ysize(4)
restore
graph export Fig5.eps, replace



**** Figure 6: Development of Birth Cohorts over Time

preserve
	collapse birthcoh, by(year)
	sc birthcoh year, c(L) ms(O) ///
	xtitle(year) ytitle("birth*1000") title("number of births 40 years ago") name(birth, replace)
restore

preserve
	set more off
	bysort year: gen first = (_n == 1)
	keep if first
	//drop id
	gen id = _n
	gen year2 = year - 1960
	list year birthcoh
	gen coef = .
	gen se = .
	forvalues i = 5/30 {
		reg birthcoh year2 L`i'.birthcoh, robust
		replace coef = _b[L`i'.birthcoh] if id == `i'
		replace se = _se[L`i'.birthcoh] if id == `i'
		}
	gen high = coef + 1.96*se
	gen low = coef - 1.96*se
	two (rcap high low id if id > 5 & id < 31) (sc coef id if id > 5 & id < 31, c(L) msize(medthick) lw(medthick)) ///
	, name(birthreg, replace) xtitle("lag") ytitle("degree of autocorrelation") title("autocorrelation of birth numbers") ///
	legend(label(1 "95% confidence interval") label(2 "correlation coefficient")) yline(0)	
restore

graph combine birth birthreg, xsize(10) ysize(4)
graph export Fig6.eps, replace


**** Figure 7: Adding Time Trend, Birth Cohort and Student Cohort

preserve
	set more off
	keep if year > 1959 & year < 2010
	collapse (sum) one (mean) studcoh birthcoh, by (year)
	gen year2 = year - 1960
	su one
	gen id = _n
	gen coef = .
	gen se = .
	tsset year2
	forvalues i = 6/19 {
		reg one year2 birthcoh studcoh L`i'.one, robust
		replace coef = _b[L`i'.one] if id == `i'
		replace se = _se[L`i'.one] if id == `i'
		}
	gen high = coef + 1.96*se
	gen low = coef - 1.96*se
	two (rcap high low id if id > 5 & id < 20) (sc coef id if id > 5 & id < 20, c(L) msize(medthick) lw(medthick)) ///
	, name(ctrlstud, replace) xtitle("lag") ytitle("degree of autocorrelation") title("ctrl timetrend, birth cohort and student cohort") ///
	legend(label(1 "95% confidence interval") label(2 "correlation coefficient")) yline(0)
restore
graph export Fig7.eps, replace


**** Table 2: Adding Time Trend and Student Cohort

preserve
	set more off
	keep if year > 1959 & year < 2010
	collapse (sum) one (mean) birthcoh studcoh, by (year)
	gen year2 = year - 1960
	reg one year2 stud L8.one, robust
	reg one year2 stud birth L8.one, robust
	gen l8one = L8.one
	sgmediation one if year2, mv(studcoh) iv(birthcoh) cv(year2 l8one)
	reg studcoh birthcoh year2 if year2 > 7, robust
restore


**** Figure 8: Number of Judges in Germany (in 1.000)

preserve
	keep if year > 1959 & year < 2010
	collapse richter, by (year)
	sc richter year, c(L) ms(O) ///
	title("total # of judges") xtitle("year") ytitle("# judges")
restore
graph export Fig8.eps, replace


**** Figure 9: GNP Development as a Proxy for earning Prospects in Law Firms

preserve
	keep if year > 1959 & year < 2010
	collapse bip, by (year)
	sc bip year, c(L) ms(O) ///
	title("gross national product") xtitle("year") ytitle("fraction of gnp 2009")
restore
graph export Fig9.eps, replace



**** Table 3: Adding Measures for Alternative Career Options

preserve
	set more off
	keep if year > 1959 & year < 2010
	collapse (sum) one (mean) birthcoh studcoh bip richter, by (year)
	gen year2 = year - 1960
	reg one year2 richter L8.one, robust
	reg one year2 studcoh richter L8.one, robust
	reg one year2 bip L8.one, robust
	reg one year2 studcoh bip L8.one, robust
	reg one year2 studcoh richter bip L8.one, robust
restore


**** Figure 10: Expected Number of Available Positions

preserve
	collapse (mean) seniorL8 (sum) one if year > 1959 & year < 2010, by(year)
	two (sc one year, c(L) ms(S)) (sc seniorL8 year, c(L) ms(Th) yaxis(2)), ///
	legend(label(1 "habilitations") label(2 "professors above age 60, L8")) ///
	xtitle(year) ytitle("# habilitations", axis(1)) ytitle("fraction professors above age 60, L8", axis(2))
restore
graph export Fig10.eps, replace


**** Table 4: Adding a Proxy for Available Positions in Academia

preserve
	keep if year > 1973 & year < 2010
	collapse (sum) one (mean) studcoh seniorL8, by (year)
	gen year2 = year - 1960
	forv i = 1974/2012 {
		qui su seniorL8 if year == `i'
		if r(mean) == . replace seniorL8 = seniorL8[_n-1] if year == `i'
		}
	tsset year2
	gen dsen = D.seniorL8
	gen dumsen = (dsen != 0)
	replace dumsen = sum(dumsen)
	bysort dumsen: egen ctdumsen = count(dumsen)
	forv i = 1/12 {
		replace dsen = dsen[_n+`i'] if dsen == 0
		}
	bysort dumsen: gen numdumsen = _n
	replace dsen = . if numdumsen == 1
	gen impseniorL8 = seniorL8 + (dsen/ctdumsen)*(numdumsen-1)
	replace impseniorL8 = seniorL8 if impseniorL8 == .
	two (sc impseniorL8 year, c(L) ms(T) msize(large)) (sc seniorL8 year, c(L) ms(Oh))
	list
	tsset year2
	reg one year2 studcoh L8.one, robust		
	reg one year2 studcoh impseniorL8 L8.one, robust
restore


**** Figure 11: Partial Autocorrelation of Residuals
**** + Table 5: Alternative Specifications of Preferred Model

preserve
	set more off
	keep if year > 1959 & year < 2010
	collapse (sum) one (mean) studcoh, by (year)
	gen year2 = year - 1960
	reg one year2 stud, robust
	predict res1, r
	pac res1, lags(16)
	reg one year2 stud L8.one, robust
	reg one year2 stud L.one L8.one, robust
	gen j1970 = (year == 1970)
	gen j1998 = (year == 1998)
	reg one year2 j1970 j1998 stud L.one L8.one, robust
	gen done = D.one
	reg done j1970 j1998 stud L.one L8.one, robust
	arima one year2 stud j1970 j1998 if year > 1967, ar(8) ma(1) robust
	arima one year2 stud j1970 j1998 if year > 1967, ar(8) ma(2) robust
	arima one year2 stud j1970 j1998 if year > 1967, ar(8) ma(3) robust
	gen l8one = L8.one
	gen l10one = L10.one
	gen l11one = L11.one
	ivregress 2sls one year2 j1970 j1998 stud (l8one = l10one)
	ivregress 2sls one year2 j1970 j1998 stud (l8one = l10one l11one)
restore
graph export Fig11.eps, replace



**** Figure 12: Out-of-sample Predictions

preserve
	keep if year > 1959
	collapse (sum) one, by (year)
	tsset year
	reg one L15.one if year < 2010, robust
	predict onehat
	two (sc one year if year < 2010, c(L) ms(S)) (sc onehat year, c(L) ms(Sh)), ///
	legend(label(1 "observed") label(2 "predicted")) title("time series prediction") ///
	xtitle("year") ytitle("# habil") name(predorig, replace)
restore

preserve
	keep if year > 1959
	collapse (sum) one (mean) studcoh, by (year)
	gen year2 = year - 1960
	tsset year2
	reg one year2 studcoh L8.one if year < 2010
	predict onehat
	list
	two (sc one year if year < 2010, c(L) ms(S)) (sc onehat year, c(L) ms(Sh)), ///
	legend(label(1 "observed") label(2 "predicted")) title("full model prediction") ///
	xtitle("year") ytitle("# habil") name(predfull, replace)
restore

graph combine predorig predfull, xsize(10) ysize(4)
graph export Fig12.eps, replace


**** image for website presentation

preserve
	keep if year > 1959
	collapse (sum) one (mean) studcoh, by (year)
	gen year2 = year - 1960
	tsset year2
	reg one year2 studcoh L8.one if year < 2010
	predict onehat
	two (sc one year if year < 2010, c(L) ms(S)) (sc onehat year, c(L) ms(Sh)), ///
	legend(label(1 "observed") label(2 "predicted")) title("hog cycle of German law professors") ///
	xtitle("year") ytitle("yearly supply") name(predfull, replace)
	graph export striking.eps, replace
	graph export striking.png, replace
restore
